@@ -14,16 +14,28 @@
 #ifndef JOBREMOTETEST_H
 #define JOBREMOTETEST_H
 
-#include <QString>
 #include <QObject>
-#include <kio/job.h>
+#include <QString>
+
+#include <kio/global.h>
+#include <kio/udsentry.h>
+
+namespace KIO
+{
+class Job;
+class FileJob;
+}
+
+class KJob;
 
 class JobRemoteTest : public QObject
 {
     Q_OBJECT
 
 public:
-    JobRemoteTest() {}
+    JobRemoteTest()
+    {
+    }
 
 private Q_SLOTS:
     void initTestCase();
@@ -36,13 +48,13 @@ private Q_SLOTS:
     void openFileRead0Bytes();
     void openFileTruncating();
 
-    //void calculateRemainingSeconds();
+    // void calculateRemainingSeconds();
 
 Q_SIGNALS:
     void exitLoop();
 
 protected Q_SLOTS:
-    //void slotEntries( KIO::Job*, const KIO::UDSEntryList& lst );
+    // void slotEntries( KIO::Job*, const KIO::UDSEntryList& lst );
     void slotGetResult(KJob *);
     void slotDataReq(KIO::Job *, QByteArray &);
     void slotResult(KJob *);
@@ -72,7 +84,9 @@ protected Q_SLOTS:
 
 private:
     void enterLoop();
-    enum { AlreadyExists = 1 };
+    enum {
+        AlreadyExists = 1
+    };
 
     int m_result;
     bool m_closeSignalCalled;
