@@ -1578,11 +1578,12 @@ void KDirListerTest::testDeleteCurrentDir()
 
     QCOMPARE(m_dirLister.spyClearDir.count(), 0);
 
-    QCOMPARE(m_dirLister.spyItemsDeleted.count(), 1);
-    const KFileItem deletedItem = m_dirLister.spyItemsDeleted.at(0).at(0).value<KFileItemList>().at(0);
-
-    QUrl currentDirUrl = QUrl::fromLocalFile(tempPath()).adjusted(QUrl::StripTrailingSlash);
-    QCOMPARE(currentDirUrl, deletedItem.url());
+    // there can be duplicated delete events
+    QVERIFY(m_dirLister.spyItemsDeleted.count() >= 1 && m_dirLister.spyItemsDeleted.count() <= 2);
+    const QUrl currentDirUrl = QUrl::fromLocalFile(tempPath()).adjusted(QUrl::StripTrailingSlash);
+    for (const auto &deletedItem : m_dirLister.spyItemsDeleted) {
+        QCOMPARE(currentDirUrl, deletedItem.at(0).value<KFileItemList>().at(0).url());
+    }
 }
 
 void KDirListerTest::testForgetDir()
@@ -1767,4 +1768,45 @@ void KDirListerTest::testUnreadableParentDirectory() {
 #endif
 }
 
+void KDirListerTest::testPathWithSquareBrackets()
+{
+#if QT_VERSION == QT_VERSION_CHECK(6, 8, 3) || QT_VERSION == QT_VERSION_CHECK(6, 9, 0)
+    QSKIP("This test is expected to fail on Qt 6.8.3 / 6.9.0");
+#endif
+    QTemporaryDir newDir(tmpDirTemplate());
+    QFile file(newDir.filePath("[test].txt"));
+    QVERIFY(file.open(QIODevice::WriteOnly | QIODevice::Text));
+    file.close();
+    MyDirLister dirLister;
+    dirLister.openUrl(QUrl::fromLocalFile(newDir.path()));
+
+    QVERIFY(dirLister.spyCompleted.wait(500));
+    QVERIFY(dirLister.isFinished());
+
+    m_refreshedItems.clear();
+    connect(&dirLister, &KCoreDirLister::refreshItems, this, &KDirListerTest::slotRefreshItems);
+    QSignalSpy spyRefreshItems(&dirLister, &KCoreDirLister::refreshItems);
+
+    QVERIFY(file.open(QIODevice::WriteOnly | QIODevice::Text));
+    file.write(QByteArray("foo"));
+    file.close();
+    QVERIFY(spyRefreshItems.wait(1000));
+    QCOMPARE(m_refreshedItems.count(), 1);
+    QCOMPARE(m_refreshedItems.at(0).first.url(), QUrl::fromLocalFile(file.fileName()));
+}
+
+void KDirListerTest::testRemoteUrlEquals()
+{
+    QUrl oldUrl(QStringLiteral("smb://foo.local"));
+    oldUrl.setPath(QStringLiteral(""));
+    QUrl newUrl(QStringLiteral("smb://foo.local"));
+    newUrl.setPath(QStringLiteral("/"));
+    m_dirLister.openUrl(oldUrl);
+    auto firstOpenedUrl = m_dirLister.url();
+    m_dirLister.openUrl(newUrl);
+    auto secondOpenedUrl = m_dirLister.url();
+
+    QCOMPARE(firstOpenedUrl, secondOpenedUrl);
+}
+
 #include "moc_kdirlistertest.cpp"
