@@ -9,11 +9,10 @@
 #ifndef KIO_CONNECTIONSERVER_H
 #define KIO_CONNECTIONSERVER_H
 
-#include "kiocore_export.h"
-
 #include <QObject>
 #include <QUrl>
-#include <memory>
+
+#include "connectionbackend_p.h"
 
 namespace KIO
 {
@@ -30,30 +29,26 @@ public:
     explicit ConnectionServer(QObject *parent = nullptr);
     ~ConnectionServer() override;
 
-    /**
+    /*!
      * Sets this connection to listen mode. Use address() to obtain the
      * address this is listening on.
      */
     void listenForRemote();
     bool isListening() const;
-    /// Closes the connection.
-    void close();
 
-    /**
+    /*!
      * Returns the address for this connection if it is listening, an empty
      * address if not.
      */
     QUrl address() const;
 
-    Connection *nextPendingConnection();
     void setNextPendingConnection(Connection *conn);
 
 Q_SIGNALS:
     void newConnection();
 
 private:
-    friend class ConnectionServerPrivate;
-    std::unique_ptr<ConnectionServerPrivate> const d;
+    ConnectionBackend *backend = nullptr;
 };
 
 } // namespace KIO
