@@ -17,6 +17,7 @@
 #include "kdiroperatoriconview_p.h"
 #include "kdirsortfilterproxymodel.h"
 #include "kfileitem.h"
+#include "kfileitemselectionemblem.h"
 #include "kfilemetapreview_p.h"
 #include "knewfilemenu.h"
 #include "kpreviewwidgetbase.h"
@@ -39,11 +40,14 @@
 #include <KUrlMimeData>
 #include <kfileitemdelegate.h>
 #include <kfilepreviewgenerator.h>
+#include <kio/askuseractioninterface.h>
 #include <kio/copyjob.h>
 #include <kio/deletejob.h>
 #include <kio/deleteortrashjob.h>
 #include <kio/jobuidelegate.h>
+#include <kio/jobuidelegatefactory.h>
 #include <kio/previewjob.h>
+#include <kio/widgetsaskuseractionhandler.h>
 #include <kpropertiesdialog.h>
 
 #include <QActionGroup>
@@ -56,6 +60,7 @@
 #include <QProgressBar>
 #include <QRegularExpression>
 #include <QScrollBar>
+#include <QScroller>
 #include <QSplitter>
 #include <QStack>
 #include <QTimer>
@@ -217,6 +222,9 @@ public:
     bool m_shouldFetchForItems = false;
     bool m_isSaving = false;
     bool m_showOpenWithActions = false;
+    bool m_isTouchEvent = false;
+    bool m_isTouchDrag = false;
+    bool m_keyNavigation = false;
 
     QList<QUrl> m_itemsToBeSetAsCurrent;
     QStringList m_supportedSchemes;
@@ -707,6 +715,7 @@ void KDirOperator::mkdir()
     d->m_newFileMenu->createDirectory();
 }
 
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(6, 15)
 KIO::DeleteJob *KDirOperator::del(const KFileItemList &items, QWidget *parent, bool ask, bool showProgress)
 {
     if (items.isEmpty()) {
@@ -737,6 +746,7 @@ KIO::DeleteJob *KDirOperator::del(const KFileItemList &items, QWidget *parent, b
 
     return nullptr;
 }
+#endif
 
 void KDirOperator::deleteSelected()
 {
@@ -751,6 +761,7 @@ void KDirOperator::deleteSelected()
     deleteJob->start();
 }
 
+#if KIOWIDGETS_BUILD_DEPRECATED_SINCE(6, 15)
 KIO::CopyJob *KDirOperator::trash(const KFileItemList &items, QWidget *parent, bool ask, bool showProgress)
 {
     if (items.isEmpty()) {
@@ -777,6 +788,7 @@ KIO::CopyJob *KDirOperator::trash(const KFileItemList &items, QWidget *parent, b
 
     return nullptr;
 }
+#endif
 
 KFilePreviewGenerator *KDirOperator::previewGenerator() const
 {
@@ -1240,6 +1252,11 @@ void KDirOperator::showOpenWithActions(bool enable)
     d->m_showOpenWithActions = enable;
 }
 
+bool KDirOperator::usingKeyNavigation()
+{
+    return d->m_keyNavigation;
+}
+
 void KDirOperator::changeEvent(QEvent *event)
 {
     QWidget::changeEvent(event);
@@ -1250,10 +1267,20 @@ bool KDirOperator::eventFilter(QObject *watched, QEvent *event)
     // If we are not hovering any items, check if there is a current index
     // set. In that case, we show the preview of that item.
     switch (event->type()) {
+    case QEvent::TouchBegin:
+        d->m_isTouchEvent = true;
+        break;
     case QEvent::MouseMove: {
-        if (d->m_preview && !d->m_preview->isHidden()) {
-            const QModelIndex hoveredIndex = d->m_itemView->indexAt(d->m_itemView->viewport()->mapFromGlobal(QCursor::pos()));
+        if (d->m_isTouchEvent) {
+            return true;
+        }
 
+        const QModelIndex hoveredIndex = d->m_itemView->indexAt(d->m_itemView->viewport()->mapFromGlobal(QCursor::pos()));
+        if (hoveredIndex.isValid()) {
+            KFileItemSelectionEmblem(d->m_itemView, hoveredIndex, this).updateSelectionEmblemRectForIndex(iconSize());
+        }
+
+        if (d->m_preview && !d->m_preview->isHidden()) {
             if (d->m_lastHoveredIndex == hoveredIndex) {
                 return QWidget::eventFilter(watched, event);
             }
@@ -1271,6 +1298,24 @@ bool KDirOperator::eventFilter(QObject *watched, QEvent *event)
         }
         break;
     }
+    case QEvent::MouseButtonPress:
+    case QEvent::MouseButtonDblClick: {
+        QMouseEvent *mouseEvent = static_cast<QMouseEvent *>(event);
+        if (mouseEvent) {
+            // Navigate and then discard the event so it doesn't select an item on the directory navigated to.
+            switch (mouseEvent->button()) {
+            case Qt::BackButton:
+                back();
+                return true;
+            case Qt::ForwardButton:
+                forward();
+                return true;
+            default:
+                break;
+            }
+        }
+        break;
+    }
     case QEvent::MouseButtonRelease: {
         if (d->m_preview != nullptr && !d->m_preview->isHidden()) {
             const QModelIndex hoveredIndex = d->m_itemView->indexAt(d->m_itemView->viewport()->mapFromGlobal(QCursor::pos()));
@@ -1280,19 +1325,13 @@ bool KDirOperator::eventFilter(QObject *watched, QEvent *event)
                 d->m_preview->clearPreview();
             }
         }
-        QMouseEvent *mouseEvent = static_cast<QMouseEvent *>(event);
-        if (mouseEvent) {
-            switch (mouseEvent->button()) {
-            case Qt::BackButton:
-                back();
-                break;
-            case Qt::ForwardButton:
-                forward();
-                break;
-            default:
-                break;
-            }
+
+        d->m_isTouchEvent = false;
+        if (d->m_isTouchDrag) {
+            d->m_isTouchDrag = false;
+            return true;
         }
+
         break;
     }
     case QEvent::HoverLeave: {
@@ -1403,6 +1442,19 @@ bool KDirOperator::eventFilter(QObject *watched, QEvent *event)
                 return true;
             }
         }
+        // Only use tab key to escape the view navigation
+        if (evt->key() == Qt::Key_Tab) {
+            d->m_keyNavigation = false;
+            d->slotSelectionChanged();
+            // When saving we need to return here,
+            // otherwise we skip over the next item with our tab press
+            // since we focus on that item in slotSelectionChanged
+            if (d->m_isSaving) {
+                return true;
+            }
+        } else {
+            d->m_keyNavigation = true;
+        }
         break;
     }
     case QEvent::Resize: {
@@ -1489,11 +1541,11 @@ QAbstractItemView *KDirOperator::createView(QWidget *parent, KFile::FileView vie
 {
     QAbstractItemView *itemView = nullptr;
     if (KFile::isDetailView(viewKind) || KFile::isTreeView(viewKind) || KFile::isDetailTreeView(viewKind)) {
-        KDirOperatorDetailView *detailView = new KDirOperatorDetailView(parent);
+        KDirOperatorDetailView *detailView = new KDirOperatorDetailView(this, parent);
         detailView->setViewMode(viewKind);
         itemView = detailView;
     } else {
-        itemView = new KDirOperatorIconView(parent, decorationPosition());
+        itemView = new KDirOperatorIconView(this, parent, decorationPosition());
     }
 
     return itemView;
@@ -1603,6 +1655,24 @@ void KDirOperator::setViewInternal(QAbstractItemView *view)
     d->m_pendingMimeTypes.clear();
     const bool listDir = (d->m_itemView == nullptr);
 
+    if (d->m_itemView) {
+        d->m_itemView->viewport()->removeEventFilter(this);
+    }
+    QScroller *scroller = QScroller::scroller(view->viewport());
+    QScrollerProperties scrollerProp;
+    scrollerProp.setScrollMetric(QScrollerProperties::AcceleratingFlickMaximumTime, 0.2); // QTBUG-88249
+    scroller->setScrollerProperties(scrollerProp);
+    scroller->grabGesture(view->viewport());
+    connect(scroller, &QScroller::stateChanged, this, [this](const QScroller::State newState) {
+        if (newState == QScroller::Inactive) {
+            d->m_isTouchEvent = false;
+        } else if (newState == QScroller::Dragging) {
+            d->m_isTouchDrag = true;
+        }
+    });
+    view->viewport()->grabGesture(Qt::TapGesture);
+    view->setAttribute(Qt::WA_AcceptTouchEvents);
+
     if (d->m_mode & KFile::Files) {
         view->setSelectionMode(QAbstractItemView::ExtendedSelection);
     } else {
@@ -1696,8 +1766,8 @@ void KDirOperator::setViewInternal(QAbstractItemView *view)
 
     const bool previewForcedToTrue = d->m_inlinePreviewState == KDirOperatorPrivate::ForcedToTrue;
     const bool previewShown = d->m_inlinePreviewState == KDirOperatorPrivate::NotForced ? d->m_showPreviews : previewForcedToTrue;
-    d->m_previewGenerator = new KFilePreviewGenerator(d->m_itemView);
     d->m_itemView->setIconSize(previewForcedToTrue ? QSize(KIconLoader::SizeHuge, KIconLoader::SizeHuge) : QSize(d->m_iconSize, d->m_iconSize));
+    d->m_previewGenerator = new KFilePreviewGenerator(d->m_itemView);
     d->m_previewGenerator->setPreviewShown(previewShown);
     action(KDirOperator::ShowPreview)->setChecked(previewShown);
 
@@ -1789,6 +1859,7 @@ void KDirOperator::selectFile(const KFileItem &item)
     QApplication::restoreOverrideCursor();
 
     Q_EMIT fileSelected(item);
+    d->m_keyNavigation = false;
 }
 
 void KDirOperator::highlightFile(const KFileItem &item)
@@ -1798,6 +1869,7 @@ void KDirOperator::highlightFile(const KFileItem &item)
     }
 
     Q_EMIT fileHighlighted(item);
+    d->m_keyNavigation = false;
 }
 
 void KDirOperator::setCurrentItem(const QUrl &url)
