@@ -789,7 +789,7 @@ WorkerResult FileProtocol::copy(const QUrl &srcUrl, const QUrl &destUrl, int _mo
 
     // copy access and modification time
     if (!wasKilled()) {
-#if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD)
+#if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD) || defined(Q_OS_HAIKU)
         // with nano secs precision
         struct timespec ut[2];
         ut[0] = buffSrc.st_atim;
@@ -845,7 +845,9 @@ WorkerResult FileProtocol::copy(const QUrl &srcUrl, const QUrl &destUrl, int _mo
         if (::chown(_dest.data(), -1 /*keep user*/, buffSrc.st_gid) == 0) {
             // as we are the owner of the new file, we can always change the group, but
             // we might not be allowed to change the owner
-            (void)::chown(_dest.data(), buffSrc.st_uid, -1 /*keep group*/);
+            if (::chown(_dest.data(), buffSrc.st_uid, -1 /*keep group*/) < 0) {
+                qCWarning(KIO_FILE) << "Couldn't chown destFile" << _dest << "(" << strerror(errno) << ")";
+            }
         } else {
             if (!tryChangeFileAttr(CHOWN, {_dest, buffSrc.st_uid, buffSrc.st_gid}, errno).success()) {
                 qCWarning(KIO_FILE) << "Couldn't preserve group for" << dest;
@@ -949,7 +951,7 @@ WorkerResult FileProtocol::listDir(const QUrl &url)
     // qDebug() << "========= LIST " << url << "details=" << details << " =========";
     UDSEntry entry;
 
-#ifndef HAVE_DIRENT_D_TYPE
+#if !(HAVE_DIRENT_D_TYPE)
     QT_STATBUF st;
 #endif
     QT_DIRENT *ep;
@@ -970,7 +972,7 @@ WorkerResult FileProtocol::listDir(const QUrl &url)
          */
         if (details == KIO::StatBasic) {
             entry.fastInsert(KIO::UDSEntry::UDS_NAME, filename);
-#ifdef HAVE_DIRENT_D_TYPE
+#if HAVE_DIRENT_D_TYPE
             entry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE, (ep->d_type == DT_DIR) ? S_IFDIR : S_IFREG);
             const bool isSymLink = (ep->d_type == DT_LNK);
 #else
@@ -993,7 +995,7 @@ WorkerResult FileProtocol::listDir(const QUrl &url)
             fullPath += filename;
 
             if (createUDSEntry(filename, encodedBasePath + QByteArray(ep->d_name), entry, details, fullPath)) {
-#if HAVE_SYS_XATTR_H
+#if HAVE_SYS_XATTR_H && HAVE_DIRENT_D_TYPE
                 if (isNtfsHidden(filename)) {
                     bool ntfsHidden = true;
 
@@ -1161,7 +1163,7 @@ WorkerResult FileProtocol::del(const QUrl &url, bool isfile)
 {
     const QString path = url.toLocalFile();
     const QByteArray _path(QFile::encodeName(path));
-    /*****
+    /*!***
      * Delete files
      *****/
 
@@ -1186,7 +1188,7 @@ WorkerResult FileProtocol::del(const QUrl &url, bool isfile)
             return WorkerResult::pass();
         }
     } else {
-        /*****
+        /*!***
          * Delete empty directory
          *****/
 
