@@ -214,7 +214,7 @@ int KFileItemActionsPrivate::insertServices(const ServiceList &list, QMenu *menu
             }
             act->setData(QVariant::fromValue(serviceAction));
             m_executeServiceActionGroup.addAction(act);
-            
+
             menu->addAction(act); // Add to toplevel menu
             ++count;
         }
@@ -453,9 +453,14 @@ bool KFileItemActionsPrivate::shouldDisplayServiceMenu(const KConfigGroup &cfg,
 
 bool KFileItemActionsPrivate::checkTypesMatch(const KConfigGroup &cfg) const
 {
-    const QStringList types = cfg.readXdgListEntry("MimeType");
+    QStringList types = cfg.readXdgListEntry("MimeType");
     if (types.isEmpty()) {
-        return false;
+        types = cfg.readEntry("ServiceTypes", QStringList());
+        types.removeAll(QStringLiteral("KonqPopupMenu/Plugin"));
+
+        if (types.isEmpty()) {
+            return false;
+        }
     }
 
     const QStringList excludeTypes = cfg.readEntry("ExcludeServiceTypes", QStringList());
@@ -575,15 +580,19 @@ int KFileItemActionsPrivate::addPluginActionsTo(QMenu *mainMenu, QMenu *actionsM
 
         KAbstractFileItemActionPlugin *abstractPlugin = m_loadedPlugins.value(pluginId);
         if (!abstractPlugin) {
-            abstractPlugin = KPluginFactory::instantiatePlugin<KAbstractFileItemActionPlugin>(jsonMetadata, this).plugin;
-            m_loadedPlugins.insert(pluginId, abstractPlugin);
+            auto result = KPluginFactory::instantiatePlugin<KAbstractFileItemActionPlugin>(jsonMetadata, this);
+            if (result) {
+                abstractPlugin = result.plugin;
+                m_loadedPlugins.insert(pluginId, abstractPlugin);
+            } else {
+                qCWarning(KIO_WIDGETS) << "Couldn't load plugin:" << pluginId << result.errorText << result.errorReason;
+            }
         }
         if (abstractPlugin) {
             connect(abstractPlugin, &KAbstractFileItemActionPlugin::error, q, &KFileItemActions::error);
             const QList<QAction *> actions = abstractPlugin->actions(m_props, m_parentWidget);
             itemCount += actions.count();
-            const QString showInSubmenu = jsonMetadata.value(QStringLiteral("X-KDE-Show-In-Submenu"));
-            if (showInSubmenu == QLatin1String("true")) {
+            if (jsonMetadata.value(QStringLiteral("X-KDE-Show-In-Submenu"), false)) {
                 actionsMenu->addActions(actions);
             } else {
                 mainMenu->addActions(actions);
@@ -812,8 +821,23 @@ QStringList KFileItemActionsPrivate::serviceMenuFilePaths()
     // Load servicemenus from new install location
     const QStringList paths =
         QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("kio/servicemenus"), QStandardPaths::LocateDirectory);
-    const QStringList fromDisk = KFileUtils::findAllUniqueFiles(paths, QStringList(QStringLiteral("*.desktop")));
-    for (const QString &fileFromDisk : fromDisk) {
+    QStringList fromDisk = KFileUtils::findAllUniqueFiles(paths, QStringList(QStringLiteral("*.desktop")));
+
+    // Also search in kservices5 for compatibility with older existing files
+    const QStringList legacyPaths =
+        QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("kservices5"), QStandardPaths::LocateDirectory);
+    const QStringList legacyFiles = KFileUtils::findAllUniqueFiles(legacyPaths, QStringList(QStringLiteral("*.desktop")));
+
+    for (const QString &path : legacyFiles) {
+        KDesktopFile file(path);
+
+        const QStringList serviceTypes = file.desktopGroup().readEntry("ServiceTypes", QStringList());
+        if (serviceTypes.contains(QStringLiteral("KonqPopupMenu/Plugin"))) {
+            fromDisk << path;
+        }
+    }
+
+    for (const QString &fileFromDisk : std::as_const(fromDisk)) {
         if (auto [_, inserted] = uniqueFileNames.insert(fileFromDisk.split(QLatin1Char('/')).last()); inserted) {
             filePaths << fileFromDisk;
         }
